@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -22,13 +22,12 @@ package org.apache.cayenne.map;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.LinkedList;
-import java.util.List;
 import java.util.Map;
-import java.util.SortedMap;
+import java.util.TreeMap;
+import java.util.function.Function;
 
 import org.apache.cayenne.CayenneRuntimeException;
 import org.apache.cayenne.ObjectId;
@@ -47,7 +46,6 @@ import org.apache.cayenne.map.event.RelationshipEvent;
 import org.apache.cayenne.util.CayenneMapEntry;
 import org.apache.cayenne.util.Util;
 import org.apache.cayenne.util.XMLEncoder;
-import org.apache.commons.collections.Transformer;
 
 /**
  * A DbEntity is a mapping descriptor that defines a structure of a database
@@ -114,40 +112,30 @@ public class DbEntity extends Entity implements ConfigurationNode, DbEntityListe
      * @since 1.1
      */
     @Override
-    public void encodeAsXML(XMLEncoder encoder) {
-        encoder.print("<db-entity name=\"");
-        encoder.print(Util.encodeXmlAttribute(getName()));
-        encoder.print('\"');
+    public void encodeAsXML(XMLEncoder encoder, ConfigurationNodeVisitor delegate) {
+        encoder.start("db-entity").attribute("name", getName());
 
         if (getSchema() != null && getSchema().trim().length() > 0) {
-            encoder.print(" schema=\"");
-            encoder.print(Util.encodeXmlAttribute(getSchema().trim()));
-            encoder.print('\"');
+            encoder.attribute("schema", getSchema().trim());
         }
-
         if (getCatalog() != null && getCatalog().trim().length() > 0) {
-            encoder.print(" catalog=\"");
-            encoder.print(Util.encodeXmlAttribute(getCatalog().trim()));
-            encoder.print('\"');
+            encoder.attribute("catalog", getCatalog().trim());
         }
 
-        encoder.println('>');
-
-        encoder.indent(1);
-        encoder.print(getAttributeMap());
+        encoder.nested(new TreeMap<>(getAttributeMap()), delegate);
 
         if (getPrimaryKeyGenerator() != null) {
-            getPrimaryKeyGenerator().encodeAsXML(encoder);
+            getPrimaryKeyGenerator().encodeAsXML(encoder, delegate);
         }
 
         if (getQualifier() != null) {
-            encoder.print("<qualifier>");
-            getQualifier().encodeAsXML(encoder);
-            encoder.println("</qualifier>");
+            encoder.start("qualifier");
+            getQualifier().encodeAsXML(encoder, delegate);
+            encoder.end();
         }
 
-        encoder.indent(-1);
-        encoder.println("</db-entity>");
+        delegate.visitDbEntity(this);
+        encoder.end();
     }
 
     /**
@@ -251,13 +239,7 @@ public class DbEntity extends Entity implements ConfigurationNode, DbEntityListe
         if (map != null) {
             for (DbEntity ent : map.getDbEntities()) {
                 for (DbRelationship relationship : ent.getRelationships()) {
-                    Iterator<DbJoin> joins = relationship.getJoins().iterator();
-                    while (joins.hasNext()) {
-                        DbJoin join = joins.next();
-                        if (join.getSource() == attr || join.getTarget() == attr) {
-                            joins.remove();
-                        }
-                    }
+                    relationship.getJoins().removeIf(join -> join.getSource() == attr || join.getTarget() == attr);
                 }
             }
         }
@@ -284,8 +266,8 @@ public class DbEntity extends Entity implements ConfigurationNode, DbEntityListe
 
     @SuppressWarnings("unchecked")
     @Override
-    public SortedMap<String, DbRelationship> getRelationshipMap() {
-        return (SortedMap<String, DbRelationship>) super.getRelationshipMap();
+    public Map<String, DbRelationship> getRelationshipMap() {
+        return (Map<String, DbRelationship>) super.getRelationshipMap();
     }
 
     /**
@@ -491,6 +473,14 @@ public class DbEntity extends Entity implements ConfigurationNode, DbEntityListe
                         }
                     }
             }
+
+            // check toDep PK for reverse relationships
+            for (DbRelationship rel : getRelationships()) {
+                DbRelationship reverse = rel.getReverseRelationship();
+                if(reverse != null && reverse.isToDependentPK() && !reverse.isValidForDepPk()) {
+                    reverse.setToDependentPK(false);
+                }
+            }
         }
 
         // handle generated key refresh
@@ -614,7 +604,7 @@ public class DbEntity extends Entity implements ConfigurationNode, DbEntityListe
     }
 
     public Collection<ObjEntity> mappedObjEntities() {
-        Collection<ObjEntity> objEntities = new HashSet<ObjEntity>();
+        Collection<ObjEntity> objEntities = new HashSet<>();
         MappingNamespace mns = getDataMap().getNamespace();
         if (mns != null) {
             for (ObjEntity objEntity : mns.getObjEntities()) {
@@ -647,7 +637,7 @@ public class DbEntity extends Entity implements ConfigurationNode, DbEntityListe
         return expression.transform(new RelationshipPathConverter(relationshipPath));
     }
 
-    final class RelationshipPathConverter implements Transformer {
+    final class RelationshipPathConverter implements Function<Object, Object> {
 
         String relationshipPath;
         boolean toMany;
@@ -667,7 +657,7 @@ public class DbEntity extends Entity implements ConfigurationNode, DbEntityListe
             }
         }
 
-        public Object transform(Object input) {
+        public Object apply(Object input) {
             if (!(input instanceof Expression)) {
                 return input;
             }
@@ -686,7 +676,7 @@ public class DbEntity extends Entity implements ConfigurationNode, DbEntityListe
         }
 
         private PathComponentIterator createPathIterator(String path) {
-            return new PathComponentIterator(DbEntity.this, path, new HashMap<String, String>());
+            return new PathComponentIterator(DbEntity.this, path, Collections.emptyMap());
             // TODO: do we need aliases here?
         }
 
@@ -706,20 +696,6 @@ public class DbEntity extends Entity implements ConfigurationNode, DbEntityListe
             return Util.join(finalPath, Entity.PATH_SEPARATOR);
         }
 
-        private String convertToPath(List<String> path) {
-            StringBuilder converted = new StringBuilder();
-            int len = path.size();
-            for (int i = 0; i < len; i++) {
-                if (i > 0) {
-                    converted.append(Entity.PATH_SEPARATOR);
-                }
-
-                converted.append(path.get(i));
-            }
-
-            return converted.toString();
-        }
-
         private void prependReversedPath(LinkedList<String> finalPath, DbRelationship relationship) {
             DbRelationship revNextDBR = relationship.getReverseRelationship();
 
