@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -398,7 +398,9 @@ public class ObjectSelect<T> extends FluentSelect<T> {
             prefetches = new PrefetchTreeNode();
         }
 
-        prefetches.addPath(path).setSemantics(semantics);
+        PrefetchTreeNode prefetchTreeNode = prefetches.addPath(path);
+        prefetchTreeNode.setSemantics(semantics);
+        prefetchTreeNode.setPhantom(false);
         replacementQuery = null;
         return this;
     }
