@@ -7,7 +7,7 @@
  *  "License"); you may not use this file except in compliance
  *  with the License.  You may obtain a copy of the License at
  *
- *    http://www.apache.org/licenses/LICENSE-2.0
+ *    https://www.apache.org/licenses/LICENSE-2.0
  *
  *  Unless required by applicable law or agreed to in writing,
  *  software distributed under the License is distributed on an
@@ -19,18 +19,13 @@
 
 package org.apache.cayenne.query;
 
+import org.apache.cayenne.CayenneRuntimeException;
 import org.apache.cayenne.access.QueryEngine;
 import org.apache.cayenne.map.DataMap;
 import org.apache.cayenne.map.DbEntity;
 import org.apache.cayenne.map.EntityResolver;
-import org.apache.cayenne.map.MapLoader;
 import org.apache.cayenne.map.ObjEntity;
-import org.apache.cayenne.map.Procedure;
 import org.apache.cayenne.map.SQLResult;
-import org.apache.cayenne.util.XMLEncoder;
-import org.apache.cayenne.util.XMLSerializable;
-import org.apache.commons.collections.IteratorUtils;
-import org.apache.commons.collections.Transformer;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -40,7 +35,8 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
-import java.util.TreeSet;
+import java.util.function.Function;
+import java.util.stream.Stream;
 
 /**
  * A query that executes unchanged (except for template preprocessing) "raw" SQL
@@ -69,18 +65,14 @@ import java.util.TreeSet;
  * 
  * @since 1.1
  */
-public class SQLTemplate extends AbstractQuery implements ParameterizedQuery, XMLSerializable {
+public class SQLTemplate extends AbstractQuery implements ParameterizedQuery {
 
 	private static final long serialVersionUID = -3073521388289663641L;
 
 	public static final String COLUMN_NAME_CAPITALIZATION_PROPERTY = "cayenne.SQLTemplate.columnNameCapitalization";
 
-	private static final Transformer nullMapTransformer = new Transformer() {
-
-		public Object transform(Object input) {
-			return (input != null) ? input : Collections.EMPTY_MAP;
-		}
-	};
+	private static final Function<Map<String, ?>, Map<String, ?>> nullMapTransformer = input ->
+			(input != null) ? input : Collections.emptyMap();
 
 	protected String defaultTemplate;
 	protected Map<String, String> templates;
@@ -89,6 +81,10 @@ public class SQLTemplate extends AbstractQuery implements ParameterizedQuery, XM
 	protected CapsStrategy columnNamesCapitalization;
 	protected SQLResult result;
 	private String dataNodeName;
+	protected boolean returnGeneratedKeys;
+
+	private List<Class<?>> resultColumnsTypes;
+	private boolean useScalar;
 
 	SQLTemplateMetadata metaData = new SQLTemplateMetadata();
 
@@ -113,11 +109,18 @@ public class SQLTemplate extends AbstractQuery implements ParameterizedQuery, XM
 		setFetchingDataRows(isFetchingDataRows);
 	}
 
+	public void setResultColumnsTypes(Class<?> ...types) {
+		if(resultColumnsTypes == null) {
+			resultColumnsTypes = new ArrayList<>(types.length);
+		}
+		Collections.addAll(resultColumnsTypes, types);
+	}
+
 	@Override
 	public void setRoot(Object value) {
 		// allow null root...
 		if (value == null) {
-			this.root = value;
+			this.root = null;
 		} else {
 			super.setRoot(value);
 		}
@@ -197,92 +200,6 @@ public class SQLTemplate extends AbstractQuery implements ParameterizedQuery, XM
 		return visitor.sqlAction(this);
 	}
 
-	/**
-	 * Prints itself as XML to the provided PrintWriter.
-	 * 
-	 * @since 1.1
-	 */
-	@Override
-	public void encodeAsXML(XMLEncoder encoder) {
-		encoder.print("<query name=\"");
-		encoder.print(getName());
-		encoder.print("\" factory=\"");
-		encoder.print("org.apache.cayenne.map.SQLTemplateBuilder");
-
-		String rootString = null;
-		String rootType = null;
-
-		if (root instanceof String) {
-			rootType = MapLoader.OBJ_ENTITY_ROOT;
-			rootString = root.toString();
-		} else if (root instanceof ObjEntity) {
-			rootType = MapLoader.OBJ_ENTITY_ROOT;
-			rootString = ((ObjEntity) root).getName();
-		} else if (root instanceof DbEntity) {
-			rootType = MapLoader.DB_ENTITY_ROOT;
-			rootString = ((DbEntity) root).getName();
-		} else if (root instanceof Procedure) {
-			rootType = MapLoader.PROCEDURE_ROOT;
-			rootString = ((Procedure) root).getName();
-		} else if (root instanceof Class<?>) {
-			rootType = MapLoader.JAVA_CLASS_ROOT;
-			rootString = ((Class<?>) root).getName();
-		} else if (root instanceof DataMap) {
-			rootType = MapLoader.DATA_MAP_ROOT;
-			rootString = ((DataMap) root).getName();
-		}
-
-		if (rootType != null) {
-			encoder.print("\" root=\"");
-			encoder.print(rootType);
-			encoder.print("\" root-name=\"");
-			encoder.print(rootString);
-		}
-
-		encoder.println("\">");
-
-		encoder.indent(1);
-
-		metaData.encodeAsXML(encoder);
-
-		if (getColumnNamesCapitalization() != CapsStrategy.DEFAULT) {
-			encoder.printProperty(COLUMN_NAME_CAPITALIZATION_PROPERTY, getColumnNamesCapitalization().name());
-		}
-
-		// encode default SQL
-		if (defaultTemplate != null) {
-			encoder.print("<sql><![CDATA[");
-			encoder.print(defaultTemplate);
-			encoder.println("]]></sql>");
-		}
-
-		// encode adapter SQL
-		if (templates != null && !templates.isEmpty()) {
-
-			// sorting entries by adapter name
-			TreeSet<String> keys = new TreeSet<String>(templates.keySet());
-			for (String key : keys) {
-				String value = templates.get(key);
-
-				if (key != null && value != null) {
-					String sql = value.trim();
-					if (sql.length() > 0) {
-						encoder.print("<sql adapter-class=\"");
-						encoder.print(key);
-						encoder.print("\"><![CDATA[");
-						encoder.print(sql);
-						encoder.println("]]></sql>");
-					}
-				}
-			}
-		}
-
-		// TODO: support parameter encoding
-
-		encoder.indent(-1);
-		encoder.println("</query>");
-	}
-
 	/**
 	 * Initializes query parameters using a set of properties.
 	 * 
@@ -307,8 +224,9 @@ public class SQLTemplate extends AbstractQuery implements ParameterizedQuery, XM
 	 */
 	@SuppressWarnings("unchecked")
 	public Iterator<Map<String, ?>> parametersIterator() {
-		return (parameters == null || parameters.length == 0) ? IteratorUtils.emptyIterator() : IteratorUtils
-				.transformedIterator(IteratorUtils.arrayIterator(parameters), nullMapTransformer);
+		return (parameters == null || parameters.length == 0)
+				? Collections.emptyIterator()
+				: Stream.of(parameters).map(nullMapTransformer).iterator();
 	}
 
 	/**
@@ -524,7 +442,7 @@ public class SQLTemplate extends AbstractQuery implements ParameterizedQuery, XM
 	 * Returns a collection of configured template keys.
 	 */
 	public synchronized Collection<String> getTemplateKeys() {
-		return (templates != null) ? templates.keySet() : Collections.<String> emptyList();
+		return (templates != null) ? templates.keySet() : Collections.emptyList();
 	}
 
 	/**
@@ -534,7 +452,7 @@ public class SQLTemplate extends AbstractQuery implements ParameterizedQuery, XM
 	 */
 	public Map<String, ?> getParams() {
 		Map<String, ?> map = (parameters != null && parameters.length > 0) ? parameters[0] : null;
-		return (map != null) ? map : Collections.<String, Object> emptyMap();
+		return (map != null) ? map : Collections.emptyMap();
 	}
 
 	/**
@@ -567,7 +485,7 @@ public class SQLTemplate extends AbstractQuery implements ParameterizedQuery, XM
 			// are not serializable with Hessian...
 			this.parameters = new Map[parameters.length];
 			for (int i = 0; i < parameters.length; i++) {
-				this.parameters[i] = parameters[i] != null ? new HashMap<>(parameters[i]) : new HashMap<String, Object>();
+				this.parameters[i] = parameters[i] != null ? new HashMap<>(parameters[i]) : new HashMap<>();
 			}
 		}
 	}
@@ -579,6 +497,7 @@ public class SQLTemplate extends AbstractQuery implements ParameterizedQuery, XM
 		return metaData.getPrefetchTree();
 	}
 
+
 	/**
 	 * Adds a prefetch.
 	 * 
@@ -595,9 +514,23 @@ public class SQLTemplate extends AbstractQuery implements ParameterizedQuery, XM
 	 * @since 4.0
 	 */
 	public void addPrefetch(PrefetchTreeNode prefetchElement) {
+		checkForDisjointNode(prefetchElement);
 		metaData.mergePrefetch(prefetchElement);
 	}
 
+	/**
+	 * Check for disjoint element and throw if it's found.
+	 * @param prefetchElement to check
+	 */
+	private void checkForDisjointNode(PrefetchTreeNode prefetchElement) {
+		if (prefetchElement.isDisjointPrefetch()) {
+			throw new CayenneRuntimeException("This query supports only 'joint' and 'disjointById' prefetching semantics.");
+		}
+		for (PrefetchTreeNode child : prefetchElement.getChildren()) {
+			checkForDisjointNode(child);
+		}
+	}
+
 	/**
 	 * @since 1.2
 	 */
@@ -712,4 +645,43 @@ public class SQLTemplate extends AbstractQuery implements ParameterizedQuery, XM
 	public void setDataNodeName(String dataNodeName) {
 		this.dataNodeName = dataNodeName;
 	}
+
+	/**
+	 * @return returnGeneratedKeys flag
+	 *
+	 * @since 4.1
+	 */
+	public boolean isReturnGeneratedKeys() {
+		return returnGeneratedKeys;
+	}
+
+	/**
+	 * Sets flag to return generated keys.
+	 *
+	 * @since 4.1
+	 */
+	public void setReturnGeneratedKeys(boolean returnGeneratedKeys) {
+		this.returnGeneratedKeys = returnGeneratedKeys;
+	}
+
+	public List<Class<?>> getResultColumnsTypes() {
+		return resultColumnsTypes;
+	}
+
+	public void setResultColumnsTypes(List<Class<?>> resultColumnsTypes) {
+		this.resultColumnsTypes = resultColumnsTypes;
+	}
+
+	/**
+	 * Sets flag to use scalars.
+	 *
+	 * @since 4.1
+	 */
+	public void setUseScalar(boolean useScalar) {
+	    this.useScalar = useScalar;
+	}
+
+	public boolean isUseScalar() {
+		return useScalar;
+	}
 }
